@@ -1,6 +1,7 @@
 import os
 import json
 import re
+from random import random
 from time import sleep
 from multiprocessing import Pool
 from typing import Optional, cast, Dict, List, Union
@@ -19,7 +20,7 @@ from rich.tree import Tree
 from rich.live import Live
 from rich.table import Table
 from scf.suse import Cache
-from scf.utils import find_by_path, file_size
+from scf.utils import find_by_path, file_size, numeric
 from requests_cache.backends.sqlite import SQLiteCache
 from scf.config import settings
 
@@ -130,7 +131,8 @@ def cache_cmd_stats() -> None:
 @cache_cmd.command("populate")
 def cache_cmd_populate(
         cve_filter: str = typer.Option(f'CVE-{datetime.now().year}-.*',
-                                       '--filter', help="Regex to apply on the CVEs to fetch."),) -> None:
+                                       '--filter', help="Regex to apply on the CVEs to fetch."),
+        workers: int = typer.Option(os.cpu_count(), '-w', '--workers', help='The number of workers that should be started'),) -> None:
     """
     Prefetch all the cve data
     """
@@ -141,10 +143,11 @@ def cache_cmd_populate(
     with Progress(transient=True) as progress:
         task = progress.add_task('Populating cache...', total=len(cve_list))
 
-        with Pool(processes=os.cpu_count()) as pool:
+        with Pool(processes=workers) as pool:
             for cve in pool.imap_unordered(prefetch_cve, cve_list):
                 progress.update(task, description=f'Populating cache...{cve}')
                 progress.advance(task)
+                sleep(random())
 
 
 @cve_cmd.command("details")
@@ -248,7 +251,7 @@ def cve_cmd_list(
         if isinstance(cves, dict):
             for cve_year, cve_list in cves.items():
                 t_y = tree.add(cve_year)
-                for cve in sorted(cve_list, reverse=True):
+                for cve in sorted(cve_list, key=numeric, reverse=True):
                     t_y.add(cve)
         else:
             for cve in cves:
